@@ -21,21 +21,23 @@ Get the user's home directory in a safe manner.
 
 =item xHOME ()
 
-just the $HOME env var, dieing if not set, and also checked against a
-couple assertments
+Just the $HOME env var, dieing if not set, and also checked against a
+couple assertments.
 
 =item xeffectiveuserhome ()
 
-just the getpwuid setting
+Just the getpwuid setting. Throws unimplemented exception on Windows
+(Raspberry, not Cygwin Perl).
 
 =item xsafehome ()
 
-always take xeffectiveuserhome, but is asserting that HOME is the same
-if set
+Always take xeffectiveuserhome (unless on Windows, in which case this
+is currently the same as xhome), but is asserting that HOME is the
+same if set.
 
 =item xhome ()
 
-take HOME if set (with assertments), otherwise xeffectiveuserhome
+Take HOME if set (with assertments), otherwise xeffectiveuserhome.
 
 =back
 
@@ -64,8 +66,13 @@ sub xHOME () {
       or die "environment variable HOME is the empty string";
     $home
       or die "environment variable HOME is false";
-    $home=~ m|^/|
-      or die "environment variable HOME does not start with a slash: '$home'";
+    if ($^O eq 'MSWin32') {
+        $home=~ m|^[a-z]+:|i # XX correct letter syntax?
+            or die "environment variable HOME does not start with a drive designator: '$home'";
+    } else {
+        $home=~ m|^/|
+            or die "environment variable HOME does not start with a slash: '$home'";
+    }
     $home
 }
 
@@ -79,13 +86,18 @@ sub xeffectiveuserhome () {
 }
 
 sub xsafehome () {
-    my $effectiveuserhome= xeffectiveuserhome;
-    if (my $e= $ENV{HOME}) {
-        $e eq $effectiveuserhome
-          or die "HOME environment variable is set to something other ".
-            "than the effective user home: '$e' vs. '$effectiveuserhome'";
+    if ($^O eq 'MSWin32') {
+        # XX or how to look it up on Windows again? If implemented, update pod.
+        xhome()
+    } else {
+        my $effectiveuserhome= xeffectiveuserhome;
+        if (my $e= $ENV{HOME}) {
+            $e eq $effectiveuserhome
+              or die "HOME environment variable is set to something other ".
+                "than the effective user home: '$e' vs. '$effectiveuserhome'";
+        }
+        $effectiveuserhome
     }
-    $effectiveuserhome
 }
 
 sub xhome () {
