@@ -18,7 +18,8 @@ FP::Values - utilities to work with Perl's multiple values ("lists")
 
 =head1 NOTE
 
-This is alpha software! Read the package README.
+This is alpha software! Read the status section in the package README
+or on the L<website|http://functional-perl.org/>.
 
 =cut
 
